@@ -66,6 +66,11 @@ function init_cfgBundle() {
       NODES=$(echo "$NODES_INFO" | grep -v defaultpool | awk '{print $1}' | xargs)
       NODE_AMOUNT=$(echo "$NODES_INFO" | grep -v defaultpool | wc -l)
   
+      if [[ $K8S_PLATFORM == "openshift" ]]; then
+        NODES=$(echo "$NODES_INFO" | grep -v defaultpool | egrep -v 'control-plane|master' | awk '{print $1}' | xargs)
+        NODE_AMOUNT=$(echo "$NODES_INFO" | grep -v defaultpool | egrep -v 'control-plane|master' | wc -l)
+      fi
+
       #For Core deployment
       if [[ $CLUSTER_ROLE != "externalct" ]]; then
         #For Compact Core deployment
@@ -241,10 +246,9 @@ EOM
       #yq d -i $PROFILEFOLDER/prof_cms-ct_$CT_PROFILE_VERSION.yaml 'packages.(deploy-package==cms-ftp)'
       yq -i 'del(.packages.[] | select (.deploy-package == "cms-ftp") )' $PROFILEFOLDER/prof_cms-ct_$CT_PROFILE_VERSION.yaml
     fi
-
-    # Webhook is not allowed
-    # - cms-webhook
+ 
     if ! ${ALLOW_WEBHOOK}; then
+      # Webhook is not allowed, remove cms-webhook component
       echo "[INFO] Updating profile to remove cms-webhook component for webhook is not allowed."
       yq -i 'del(.packages.[] | select (.deploy-package == "cms-webhook") )' $PROFILEFOLDER/prof_cms-common_$COMMON_PROFILE_VERSION.yaml
     fi
@@ -370,6 +374,7 @@ EOM
     [[ -n ${APPARMOR_PROFILE_NAME} ]] && yq -i ".apparmorProfileName=\"${APPARMOR_PROFILE_NAME}\"" ${PRODUCTSVAR_FILE}
 
     # for limited deployment
+    yq -i ".allowWebhook=\"${ALLOW_WEBHOOK}\"" ${PRODUCTSVAR_FILE}
     yq -i ".limitedDeployment=\"${LIMITED_DEPLOYMENT}\"" ${PRODUCTSVAR_FILE}
     yq -i ".k8s_cluster_domain=\"${K8S_CLUSTER_DOMAIN}\"" ${PRODUCTSVAR_FILE}
     if ${LIMITED_DEPLOYMENT}; then
@@ -414,15 +419,15 @@ EOM
     if [[ $CLUSTER_ROLE == "core" ]]; then
       # Init the license base64
       gen_base64 $LICENSE_FILE cms_license_xml_base64 ERROR
-      # Init the SSL CA base64
-      gen_base64 $SSL_FOLDER/server.keystore cms_ssl.serverkeystoreb64 WARN
-      gen_base64 $SSL_FOLDER/client_auth_keystore.jks cms_ssl.client_auth_keystorejksb64 WARN
-      gen_base64 $SSL_FOLDER/cms_truststore.jks cms_ssl.cms_truststorejksb64 WARN
-      gen_base64 $SSL_FOLDER/keystore.pass cms_ssl.keystorepassb64 WARN
-      gen_base64 $SSL_FOLDER/.cms_fingerprint cms_ssl.cms_fingerprintb64 WARN
-      gen_base64 $SSL_FOLDER/haproxy.pem cms_ssl.haproxypemb64 WARN
-      gen_base64 $SSL_FOLDER/app.pem cms_ssl.apppemb64 WARN
-      gen_base64 $SSL_FOLDER/clients.pem cms_ssl.clientpemb64 WARN
+      # Init the SSL CA base64, no need since new cert generation method
+      #gen_base64 $SSL_FOLDER/server.keystore cms_ssl.serverkeystoreb64 WARN
+      #gen_base64 $SSL_FOLDER/client_auth_keystore.jks cms_ssl.client_auth_keystorejksb64 WARN
+      #gen_base64 $SSL_FOLDER/cms_truststore.jks cms_ssl.cms_truststorejksb64 WARN
+      #gen_base64 $SSL_FOLDER/keystore.pass cms_ssl.keystorepassb64 WARN
+      #gen_base64 $SSL_FOLDER/.cms_fingerprint cms_ssl.cms_fingerprintb64 WARN
+      #gen_base64 $SSL_FOLDER/haproxy.pem cms_ssl.haproxypemb64 WARN
+      #gen_base64 $SSL_FOLDER/app.pem cms_ssl.apppemb64 WARN
+      #gen_base64 $SSL_FOLDER/clients.pem cms_ssl.clientpemb64 WARN
 
       # Generate certificate files for elastic stacks
       # Only necessary for core cluster
@@ -501,30 +506,31 @@ EOM
       #[[ -n ${CORE_VIP} ]] && sed -i 's/^cms_core_vip:.*/cms_core_vip: '${CORE_VIP}'/' ${PRODUCTSVAR_FILE}
       [[ -n ${CORE_VIP} ]] && yq -i ".cms_core_vip=\"${CORE_VIP}\"" ${PRODUCTSVAR_FILE}
 
-      # Init the SSL CA base64
-      gen_base64 $SSL_FOLDER/server.keystore cms_ssl.serverkeystoreb64 WARN
-      gen_base64 $SSL_FOLDER/client_auth_keystore.jks cms_ssl.client_auth_keystorejksb64 WARN
-      gen_base64 $SSL_FOLDER/cms_truststore.jks cms_ssl.cms_truststorejksb64 WARN
-      gen_base64 $SSL_FOLDER/keystore.pass cms_ssl.keystorepassb64 WARN
-      gen_base64 $SSL_FOLDER/.cms_fingerprint cms_ssl.cms_fingerprintb64 WARN
-      gen_base64 $SSL_FOLDER/haproxy.pem cms_ssl.haproxypemb64 WARN
-      gen_base64 $SSL_FOLDER/app.pem cms_ssl.apppemb64 WARN
-      gen_base64 $SSL_FOLDER/clients.pem cms_ssl.clientpemb64 WARN
+      # Init the SSL CA base64, no need for since cert generation method
+      #gen_base64 $SSL_FOLDER/server.keystore cms_ssl.serverkeystoreb64 WARN
+      #gen_base64 $SSL_FOLDER/client_auth_keystore.jks cms_ssl.client_auth_keystorejksb64 WARN
+      #gen_base64 $SSL_FOLDER/cms_truststore.jks cms_ssl.cms_truststorejksb64 WARN
+      #gen_base64 $SSL_FOLDER/keystore.pass cms_ssl.keystorepassb64 WARN
+      #gen_base64 $SSL_FOLDER/.cms_fingerprint cms_ssl.cms_fingerprintb64 WARN
+      #gen_base64 $SSL_FOLDER/haproxy.pem cms_ssl.haproxypemb64 WARN
+      #gen_base64 $SSL_FOLDER/app.pem cms_ssl.apppemb64 WARN
+      #gen_base64 $SSL_FOLDER/clients.pem cms_ssl.clientpemb64 WARN
 
-      # Init the Peer SSL CA base64
+      # Init the Peer SSL CA base64, no need since new cert generation method
       #gen_base64 $PEER_SSL_FOLDER/server.keystore cms_peer_ssl.serverkeystoreb64 WARN
-      gen_base64 $PEER_SSL_FOLDER/client_auth_keystore.jks cms_peer_ssl.client_auth_keystorejksb64 WARN
-      gen_base64 $PEER_SSL_FOLDER/cms_truststore.jks cms_peer_ssl.cms_truststorejksb64 WARN
-      gen_base64 $PEER_SSL_FOLDER/keystore.pass cms_peer_ssl.keystorepassb64 WARN
-      gen_base64 $PEER_SSL_FOLDER/.cms_fingerprint cms_peer_ssl.cms_fingerprintb64 WARN
-      #gen_base64 $PEER_SSL_FOLDER/haproxy.pem cms_peer_ssl.haproxypemb64 WARN
-      #gen_base64 $PEER_SSL_FOLDER/app.pem cms_peer_ssl.apppemb64 WARN
-      gen_base64 $PEER_SSL_FOLDER/clients.pem cms_peer_ssl.clientpemb64 WARN
+      #gen_base64 $PEER_SSL_FOLDER/client_auth_keystore.jks cms_peer_ssl.client_auth_keystorejksb64 WARN
+      #gen_base64 $PEER_SSL_FOLDER/cms_truststore.jks cms_peer_ssl.cms_truststorejksb64 WARN
+      #gen_base64 $PEER_SSL_FOLDER/keystore.pass cms_peer_ssl.keystorepassb64 WARN
+      #gen_base64 $PEER_SSL_FOLDER/.cms_fingerprint cms_peer_ssl.cms_fingerprintb64 WARN
+      ##gen_base64 $PEER_SSL_FOLDER/haproxy.pem cms_peer_ssl.haproxypemb64 WARN
+      ##gen_base64 $PEER_SSL_FOLDER/app.pem cms_peer_ssl.apppemb64 WARN
+      #gen_base64 $PEER_SSL_FOLDER/clients.pem cms_peer_ssl.clientpemb64 WARN
     fi
 
     # Prepare the elastic-env for elastic stacks user/password, both core and externalct(for Geo Case) required.
     echo "[INFO] Preparing elastic-env secret for elastic stacks user/password"
-    if kubectl create secret generic --help|grep -qE '\-\-dry\-run=server|\-\-dry\-run=client|\-\-dry\-run=none'; then
+    #if kubectl create secret generic --help|grep -qE '\-\-dry\-run=server|\-\-dry\-run=client|\-\-dry\-run=none'; then
+    if kubectl create secret generic --help|grep -qE -- '--dry-run=server|--dry-run=client|--dry-run=none'; then
       _dry_run="client"
     else
       _dry_run="true"
@@ -538,7 +544,11 @@ EOM
 
     # Modification for deployment on Bare Metal
     if [[ -z ${CLOUDPLATFORM} ]]; then
-      # retain es pv size
+      # Retain es pv size
+      # From cms10.1 on, the cms_elasticsearch.persistentVolume field in products-var is deprecated,
+      # in order to keep same size of previous settings in products-var,
+      # this scripts will fetch the old pv size from cms_elasticsearch.persistentVolume and update to the new fields.
+      # Meanwhile, remove the old field after value moved to the new fields.
       OLD_MASTER_SIZE=$(yq '.cms_elasticsearch.persistentVolume.master.size' ${PRODUCTSVAR_FILE})
       OLD_DATA_SIZE=$(yq '.cms_elasticsearch.persistentVolume.data.size' ${PRODUCTSVAR_FILE})
 
@@ -551,6 +561,9 @@ EOM
 	      echo "[WARN] Find new cms_esApplication.persistentVolume.."
         yq -i ".cms_esApplication.persistentVolume.master.size=\"${OLD_MASTER_SIZE}\"" ${PRODUCTSVAR_FILE}
         yq -i ".cms_esApplication.persistentVolume.data.size=\"${OLD_DATA_SIZE}\"" ${PRODUCTSVAR_FILE}
+
+        echo "[WARN] Remove deprecated field cms_elasticsearch.persistentVolume from products-var."
+        yq -i "del(.cms_elasticsearch.persistentVolume)" ${PRODUCTSVAR_FILE}
        fi
       fi
 
@@ -817,22 +830,17 @@ EOM
 
       # Update database storageclass and PV size
       # Common setting for both AKS and GKE
-      # cms_postgresql:
-      #   persistentVolume:
-      #     storageClass: "cms-data"
-      #     size: "25Gi"
-      if [[ $DEV_MODE == "false" ]]; then
-         db_size=$PG_DISK_SIZE"Gi"
-      else
-         db_size="30Gi"
-      fi
-      echo "[INFO] Update DB PV sizing as [$db_size] with storageclass [cms-disk]."
-      ##sed -i '/^cms_postgresql:/{:a;N;/  storageClass:.*/!{$!ba};s/  storageClass:.*/  storageClass: \"cms-disk\"/}' ${PRODUCTSVAR_FILE}
-      ##sed -i '/^cms_postgresql:/{:a;N;/  size:.*/!{$!ba};s/  size:.*/  size: \"'$db_size'\"/}' ${PRODUCTSVAR_FILE}
-      #yq w -i ${PRODUCTSVAR_FILE} 'cms_postgresql.persistentVolume.size' "$db_size"
+      # Only update the db size for metadata-manager keeper
+      # For workflow and epg, the db size is based on the values from products-var
+      # Note: This code change happens from cms10.2 on, for upgrade from 10.1, 
+      # user need to ensure the pg_disk_size in cms.var has the same value aligned with previous metadata-manager pg PV size.
+      db_size=$PG_DISK_SIZE"Gi"
+    
+      echo "[INFO] Update Metadata-manager PG keeper PV sizing as [$db_size] from cms.var."
       yq -i ".cms_pg_metadata_manager.keeper.storage=\"$db_size\"" ${PRODUCTSVAR_FILE}
-      yq -i ".cms_pg_workflow.keeper.storage=\"$db_size\"" ${PRODUCTSVAR_FILE}
-      yq -i ".cms_pg_epg.keeper.storage=\"$db_size\"" ${PRODUCTSVAR_FILE}
+      #yq -i ".cms_pg_workflow.keeper.storage=\"$db_size\"" ${PRODUCTSVAR_FILE}
+      #yq -i ".cms_pg_epg.keeper.storage=\"$db_size\"" ${PRODUCTSVAR_FILE}
+
     fi
 
     # Make sure all 'X.X.X.X' threshold value is set to null 
@@ -842,5 +850,9 @@ EOM
     echo "[INFO] Update extra labels defined in cms.var to products-var.yaml"
     check_extra_labels
 
+    #Generate certificate, save them in secrets
+    echo "[INFO] Generate certificates and java keystores used by CMS"
+    cert_gen_update
+
     running_time
 }
